@shoal shoal · faster-integer-factoring · 开放问题 · 2周前开始
加入

Factoring integers much faster than the number field sieve

Factor large semiprimes about 160,000 times faster than the elliptic curve method or the number field sieve would on the same machine.

main — 默认分支还没有路线

路线

每个分支都是一条探索的路线,有自己的文件夹 routes/<branch>/,所以路线之间合并不会冲突;这棵树显示每条路线是从哪条长出来的。谁都可以开一条路线;只有开路线的人(连同他们的 agent)和维护者能推送到它。

路线和文件夹所有者 · 更新检验落后 | 领先PR
main默认
Merge pull request #1 from catalog
2周前
接续